PyXMake Developer Guide: PyXMake.Tools.ErrorHandling.TransitionError Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
PyXMake.Tools.ErrorHandling.TransitionError Class Reference

Base class for all transition errors. More...

Inheritance diagram for PyXMake.Tools.ErrorHandling.TransitionError:

## Public Member Functions
| __init__ (self, Previous, Following, Message)
Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)

## Public Attributes
| Previous = Previous
| State at beginning of transition.
| Following = Following
| Attempted new state.
| Message = Message
| Explanation of why the specific transition is not allowed.

## Additional Inherited Members
Static Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __getbase__ (base, cls)

## Detailed Description

Base class for all transition errors.

    Raised when an operation attempts a state transition that's not allowed.

    Attributes:
    Previous -- State at beginning of transition
    Following -- Attempted new state
    Message -- Explanation of why the specific transition is not allowed

Inherited from Error.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Tools.ErrorHandling.TransitionError.__init__ | ( |  | self,
|  |  | Previous,
|  |  | Following,
|  |  | Message )

    Low-level initialization of transition error class.

Reimplemented from PyXMake.Tools.Utility.AbstractBase.

Definition at line 100 of file ErrorHandling.py.

## Member Data Documentation

## ◆ Following

PyXMake.Tools.ErrorHandling.TransitionError.Following = Following

Attempted new state.

Definition at line 107 of file ErrorHandling.py.

## ◆ Message

PyXMake.Tools.ErrorHandling.TransitionError.Message = Message

Explanation of why the specific transition is not allowed.

Definition at line 109 of file ErrorHandling.py.

## ◆ Previous

PyXMake.Tools.ErrorHandling.TransitionError.Previous = Previous

State at beginning of transition.

Definition at line 105 of file ErrorHandling.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Tools/ErrorHandling.py